@@ -1,18 +1,11 @@
-from timeit import timeit
-import time
-
 from pythautomata.base_types.sequence import Sequence
 from pythautomata.base_types.alphabet import Alphabet
-from collections import namedtuple
 from pymodelextractor.teachers.teacher import Teacher
 from pymodelextractor.learners.learner import Learner
 from pymodelextractor.learners.observation_table_learners.observation_table import epsilon
-#from observation_tables.lstar_observation_table import LStarObservationTable
 from pymodelextractor.learners.observation_table_learners.translators.fa_observation_table_translator import FAObservationTableTranslator
 from pymodelextractor.learners.learning_result import LearningResult
 
-numberOfExecutionsForAverage = 100
-
 class LStarLearner(Learner):
 
     def __init__(self):
@@ -107,11 +100,12 @@ class LStarLearner(Learner):
 
     def _learning_results_for(self, model):
         numberOfStates = len(model.states) if model is not None else 0
-        return LearningResult(model, numberOfStates)
-
-    def average_learning_execution_time_for(self, teacher: Teacher):
-        learning = timeit_wrapper(self.learn, teacher=teacher)
-        return timeit(learning, number=numberOfExecutionsForAverage) / numberOfExecutionsForAverage
+        info = {
+            'equivalence_queries_count': self._teacher.equivalence_queries_count,
+            'last_token_weight_queries_count': self._teacher.membership_queries_count,
+            'observation_table': self._observation_table
+        }
+        return LearningResult(model, numberOfStates, info)
 
     # Helper methods
     @property
